@@ -1,7 +1,7 @@
 """
 Type annotations for comprehendmedical service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/)
 
 Usage::
 
@@ -82,7 +82,7 @@ class Exceptions:
 class ComprehendMedicalClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/)
     """
 
     meta: ClientMeta
@@ -93,7 +93,7 @@ class ComprehendMedicalClient(BaseClient):
         ComprehendMedicalClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -101,7 +101,7 @@ class ComprehendMedicalClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#can_paginate)
         """
 
     def describe_entities_detection_v2_job(
@@ -111,7 +111,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets the properties associated with a medical entities detection job.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_entities_detection_v2_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#describe_entities_detection_v2_job)
         """
 
     def describe_icd10_cm_inference_job(
@@ -121,7 +121,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets the properties associated with an InferICD10CM job.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_icd10_cm_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#describe_icd10_cm_inference_job)
         """
 
     def describe_phi_detection_job(self, *, JobId: str) -> DescribePHIDetectionJobResponseTypeDef:
@@ -130,7 +130,7 @@ class ComprehendMedicalClient(BaseClient):
         detection job.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_phi_detection_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#describe_phi_detection_job)
         """
 
     def describe_rx_norm_inference_job(
@@ -140,7 +140,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets the properties associated with an InferRxNorm job.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_rx_norm_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#describe_rx_norm_inference_job)
         """
 
     def describe_snomedct_inference_job(
@@ -150,7 +150,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets the properties associated with an InferSNOMEDCT job.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_snomedct_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_snomedct_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#describe_snomedct_inference_job)
         """
 
     def detect_entities(self, *, Text: str) -> DetectEntitiesResponseTypeDef:
@@ -158,7 +158,7 @@ class ComprehendMedicalClient(BaseClient):
         The `DetectEntities` operation is deprecated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#detect_entities)
         """
 
     def detect_entities_v2(self, *, Text: str) -> DetectEntitiesV2ResponseTypeDef:
@@ -168,7 +168,7 @@ class ComprehendMedicalClient(BaseClient):
         confidence score on that information.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities_v2)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#detect_entities_v2)
         """
 
     def detect_phi(self, *, Text: str) -> DetectPHIResponseTypeDef:
@@ -177,7 +177,7 @@ class ComprehendMedicalClient(BaseClient):
         returns the entity category, location, and confidence score for each entity.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_phi)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#detect_phi)
         """
 
     def generate_presigned_url(
@@ -191,7 +191,7 @@ class ComprehendMedicalClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#generate_presigned_url)
         """
 
     def infer_icd10_cm(self, *, Text: str) -> InferICD10CMResponseTypeDef:
@@ -201,7 +201,7 @@ class ComprehendMedicalClient(BaseClient):
         knowledge base from the Centers for Disease Control.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_icd10_cm)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#infer_icd10_cm)
         """
 
     def infer_rx_norm(self, *, Text: str) -> InferRxNormResponseTypeDef:
@@ -211,7 +211,7 @@ class ComprehendMedicalClient(BaseClient):
         Library of Medicine.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_rx_norm)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#infer_rx_norm)
         """
 
     def infer_snomedct(self, *, Text: str) -> InferSNOMEDCTResponseTypeDef:
@@ -223,7 +223,7 @@ class ComprehendMedicalClient(BaseClient):
         **Re...
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_snomedct)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_snomedct)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#infer_snomedct)
         """
 
     def list_entities_detection_v2_jobs(
@@ -237,7 +237,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets a list of medical entity detection jobs that you have submitted.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_entities_detection_v2_jobs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#list_entities_detection_v2_jobs)
         """
 
     def list_icd10_cm_inference_jobs(
@@ -251,7 +251,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets a list of InferICD10CM jobs that you have submitted.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_icd10_cm_inference_jobs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#list_icd10_cm_inference_jobs)
         """
 
     def list_phi_detection_jobs(
@@ -266,7 +266,7 @@ class ComprehendMedicalClient(BaseClient):
         submitted.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_phi_detection_jobs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#list_phi_detection_jobs)
         """
 
     def list_rx_norm_inference_jobs(
@@ -280,7 +280,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets a list of InferRxNorm jobs that you have submitted.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_rx_norm_inference_jobs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#list_rx_norm_inference_jobs)
         """
 
     def list_snomedct_inference_jobs(
@@ -294,7 +294,7 @@ class ComprehendMedicalClient(BaseClient):
         Gets a list of InferSNOMEDCT jobs a user has submitted.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_snomedct_inference_jobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_snomedct_inference_jobs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#list_snomedct_inference_jobs)
         """
 
     def start_entities_detection_v2_job(
@@ -313,7 +313,7 @@ class ComprehendMedicalClient(BaseClient):
         documents.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_entities_detection_v2_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#start_entities_detection_v2_job)
         """
 
     def start_icd10_cm_inference_job(
@@ -332,7 +332,7 @@ class ComprehendMedicalClient(BaseClient):
         ICD-10-CM ontology.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_icd10_cm_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#start_icd10_cm_inference_job)
         """
 
     def start_phi_detection_job(
@@ -350,7 +350,7 @@ class ComprehendMedicalClient(BaseClient):
         Starts an asynchronous job to detect protected health information (PHI).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_phi_detection_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#start_phi_detection_job)
         """
 
     def start_rx_norm_inference_job(
@@ -369,7 +369,7 @@ class ComprehendMedicalClient(BaseClient):
         RxNorm ontology.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_rx_norm_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#start_rx_norm_inference_job)
         """
 
     def start_snomedct_inference_job(
@@ -388,7 +388,7 @@ class ComprehendMedicalClient(BaseClient):
         SNOMED-CT ontology.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_snomedct_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_snomedct_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#start_snomedct_inference_job)
         """
 
     def stop_entities_detection_v2_job(
@@ -398,7 +398,7 @@ class ComprehendMedicalClient(BaseClient):
         Stops a medical entities detection job in progress.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_entities_detection_v2_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#stop_entities_detection_v2_job)
         """
 
     def stop_icd10_cm_inference_job(self, *, JobId: str) -> StopICD10CMInferenceJobResponseTypeDef:
@@ -406,7 +406,7 @@ class ComprehendMedicalClient(BaseClient):
         Stops an InferICD10CM inference job in progress.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_icd10_cm_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#stop_icd10_cm_inference_job)
         """
 
     def stop_phi_detection_job(self, *, JobId: str) -> StopPHIDetectionJobResponseTypeDef:
@@ -414,7 +414,7 @@ class ComprehendMedicalClient(BaseClient):
         Stops a protected health information (PHI) detection job in progress.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_phi_detection_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#stop_phi_detection_job)
         """
 
     def stop_rx_norm_inference_job(self, *, JobId: str) -> StopRxNormInferenceJobResponseTypeDef:
@@ -422,7 +422,7 @@ class ComprehendMedicalClient(BaseClient):
         Stops an InferRxNorm inference job in progress.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_rx_norm_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#stop_rx_norm_inference_job)
         """
 
     def stop_snomedct_inference_job(self, *, JobId: str) -> StopSNOMEDCTInferenceJobResponseTypeDef:
@@ -430,5 +430,5 @@ class ComprehendMedicalClient(BaseClient):
         Stops an InferSNOMEDCT inference job in progress.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_snomedct_inference_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_snomedct_inference_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client/#stop_snomedct_inference_job)
         """
