@@ -1,7 +1,7 @@
 """
 Type annotations for comprehendmedical service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/literals/)
 
 Usage::
 
@@ -43,6 +43,7 @@ __all__ = (
     "ComprehendMedicalServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -273,6 +274,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -374,6 +376,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -470,3 +473,12 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal[
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
